超能陆战队 (豆瓣)
Description: 超能陆战队电影简介和剧情介绍,超能陆战队影评、图片、预告片、影讯、论坛、在线购票
Keywords: 超能陆战队,Big Hero 6,超能陆战队影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.115豆瓣电影Top250

# 超能陆战队 Big Hero 6 (2014)

导演: 唐·霍尔 / 克里斯·威廉姆斯
编剧: 乔丹·罗伯茨 / 丹尼尔·吉尔森 / 罗伯特·L·贝尔德
主演: 斯科特·安第斯 / 瑞恩·波特 / 丹尼尔·海尼 / T·J·米勒 / 郑智麟 / 小达蒙·韦恩斯 / 珍尼希斯·罗德里格兹 / 詹姆斯·克伦威尔 / 艾伦·图代克 / 玛娅·鲁道夫 / 亚布拉哈姆·本鲁比 / 凯蒂·洛斯 / 比利·布什 / 丹尼尔·吉尔森 / 保罗·布里格斯
类型: 喜剧 / 动作 / 科幻 / 动画 / 冒险
官方网站: www.disneyanimation.com/projects/bighero6
制片国家/地区: 美国
语言: 英语
上映日期: 2015-02-28(中国大陆) / 2020-07-31(中国大陆重映) / 2014-10-23(东京电影节) / 2014-11-07(美国)
片长: 102分钟
又名: 大英雄联盟(港) / 大英雄天团(台) / 六大英雄 / (●—●)
IMDb: tt2245084
豆瓣评分
引用
8.7
960148人评价
5星
48.3%
4星
40.9%
3星
10.1%
2星
0.6%
1星
0.1%
好于 97% 动画片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 超能陆战队的剧情简介 · · · · · ·

未来世界的超级都市旧京山（San Fransokyo），热爱发明创造的天才少年小宏，在哥哥泰迪的鼓励下参加了罗伯特·卡拉汉教授主持的理工学院机器人专业的入学大赛。他凭借神奇的微型磁力机器人赢得观众、参赛者以及考官的一致好评，谁知突如其来的灾难却将小宏的梦想和人生毁于一旦。大火烧毁了展示会场，而哥哥为了救出受困的卡拉汉教授命丧火场。身心饱受创伤的小宏闭门不出，哥哥生前留下的治疗型机器人大白则成为安慰他的唯一伙伴。原以为微型机器人也毁于火灾，谁知小宏和大白竟意外发现有人在某座废弃工厂内大批量地生产他的发明。
稍后哥哥的朋友们弗雷德等人也加入进来，他们穿上小宏发明的超级战士战斗装备，和怀有险恶阴谋的神秘对手展开较量…… ©豆瓣

## 超能陆战队的演职员 · · · · · · ( 全部 42 )

- 唐·霍尔 导演
- 克里斯·威廉姆斯 导演
- 斯科特·安第斯 配 大白 Baymax
- 瑞恩·波特 配 小宏 Hiro Hamada
- 丹尼尔·海尼 配 泰迪 Tadashi
- T·J·米勒 配 弗雷德 Fred

## 超能陆战队的视频和图片 · · · · · · ( 预告片30 | 添加视频评论 | 图片1964 · 添加 )

## 超能陆战队的获奖情况 · · · · · · ( 全部 )

- 第87届奥斯卡金像奖
- 最佳动画长片
- 唐·霍尔 / 克里斯·威廉姆斯 / 洛伊·康利

- 第72届金球奖
- 电影类 最佳动画长片(提名)

- 第42届动画安妮奖
- 最佳动画长片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  大闹天宫

  哈尔的移动城堡

  神偷奶爸

  怪兽电力公司

  幽灵公主

  玩具总动员

  驯龙高手

  风之谷

  冰川时代

我要写短评

## 超能陆战队的短评 · · · · · · ( 全部 188608 条 )

热门 / 最新 / 好友

### 746 有用 岚枫十字 看过 2014-11-08 14:13:30

迪士尼最新的Hyperion渲染器，渲染旧金山全景，几千个光源，无数的precedural shading...碉堡... 剧情的话Hero's journy，感情带动很好。动画感觉比Dragon2有看头~ 忘了说一句，记得看彩蛋~ Stan Lee的哏儿~

### 526 有用 Sigmund Fraud 看过 2014-11-29 16:49:07

三番和东京，动画和机器人，樱花和Caltech，我们的城市我们的大学我们的专业，这部片子对我的意义不一样，我真的惊。呆。了。对最近在想皮肤材质和场景建模和粒子特效的我也格外有教科书的意义。再见Monster Co，你现在排第二了！（DC在这个我所看过的最彩的彩蛋里被Marvel黑出翔~~~！！！！

### 2789 有用 影志 看过 2015-01-12 22:39:00

故事不新鲜，但角色有新意。几处萌点和泪点全部来自大白，大白的陪伴，让人想起的不仅仅是：大熊身边的哆啦A梦、教授帕克的忠犬八公、坚守地球的WALL·E、邻家的多多龙、维克多的科学怪狗、小嗝嗝身边的无牙、库珀身边的机器人Case、山姆身边的Gerty、Wallace身边的Gromit...

### 434 有用 一位少男 看过 2014-10-26 22:03:13

史上最萌胖子诞生！要抱抱！彩蛋里的斯坦·李也是蛮拼的！

### 1127 有用 Bill 看过 2014-11-07 03:39:51

好想戳爆胖子看会发生什么……

> 更多短评 188608条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 超能陆战队的影评 · · · · · · ( 全部 927 条 )

热门 / 最新 / 好友
Dr希鲁鲁克 2015-03-05 08:38:43

## 这是一个关于学术圈反腐的玄幻故事

在遥远的世界中有一座旧金山，山下小村庄里有一位天赋异禀的少年，浓眉大眼，天庭饱满，骨骼清奇，年纪轻轻便可以气御物，炼有一宝，江湖人称黑曜星。少年小宏靠着黑曜星与人打架，不务正业，踢遍附近武馆，惹下不少祸端。这小宏有一哥哥，在旧金山上的斯坦福派里，跟随教授卡... (展开)
1968 137 168回应 收起
Angelina.ae 2015-02-28 19:13:45

## 心有猛虎，轻嗅蔷薇：——《超能陆战队》影评

这篇影评可能有剧透

——世界上唯一比给予生命更美好的，就是让生命充满爱。 这部充满着笑点和泪点的动画实在有太多值得品评和收藏之处，然而促使我写下这片影评的，却是一个再小不过的细节：身着重装铠甲的Baymax刚刚站定、摆好Hiro要求的pose，这时一只蝴蝶飘然落在“钢铁巨人”的指尖，大白的神... (展开)
2905 66 182回应 收起
Kloud 2014-11-09 17:28:41

## 一步之遥的遗憾，Big Hero 6（超能陆战队）

迪斯尼的新片Big Hero 6，中文翻译超能陆战队、六大英雄或者大英雄联盟（WTF），之后用BH6作为统称， 毫无疑问是今年年底最让人期待的动画电影。贴片沉睡魔咒无比惊艳的clip 1 预告（在今年看过所有电影的贴片预告里，这个预告的反响热烈程度远超其他，当排第一）让其第一次映... (展开)
541 42 81回应 收起
Fleetwood 2014-11-08 14:16:52

## 漫威小法好——非主流的胜利(长文，回顾漫威的2014）

这篇影评可能有剧透

首先要恭喜漫威/迪士尼，又是名利双收的一场好戏，我似乎已经看到漫威在2014年的漂亮收官。在进入正题之前，我想回顾一下漫威的一年。算上“贴牌”的福克斯和索尼，今年漫威漫画改编的电影有五部之多，可谓是斯坦李存在感爆棚的一年。 从这五部来看，我觉得和往... (展开)
459 71 59回应 收起
马泽尔法克尔 2014-11-18 17:56:16

## 我不是胖嘟嘟，我只是气很足 (◕——◕)

这篇影评可能有剧透

我不是胖嘟嘟，我只是气很足 (◕——◕) “决定是你了，宝石海星！”男主角滨田宏凭借出色的机器人制造与操控技术外加扮猪吃老虎的战术，在机器人擂台赛上小赚一笔。成为超级英雄之前的中二少年常常喜欢不顾家人的反对跑到这种不合法的竞技场里去胡闹一阵。不巧的是主角... (展开)
323 32 43回应 收起
三嘟 2015-02-04 20:55:08

## 炫技卖萌不是好兆头

今年的奥斯卡最佳动画片争夺战呈现出和去年相同的格局：美国三部、欧洲一部、日本一部。不过，比起去年《冰雪奇缘》+《疯狂原始人》+《卑鄙的我》2这样的豪华阵容，今年的三部美国片整体降档。《驯龙高手》2和《盒子怪》只能说是及格，这部《超能陆战队》稍好一些，除了故事更... (展开)
252 38 54回应 收起
小海 2015-03-01 17:09:07

## 好电影是最佳的标尺

国内电影观众中一直存在一种十分奇特的心理认知：动画片，是给小孩子看的。于是每每逢年过节，只要有动画上映，影厅总是挤满成群结队的小朋友，他们中保持安静的只占少数，其他大多数主要承载的是以下作用：大声喧哗，大力鼓掌，惊声尖叫，夸张赞叹，上蹿下跳，踢凳踹椅，尿频... (展开)
263 31 53回应 收起
想回教室去 2015-02-04 17:17:02

## 关于《超能陆战队》你应该知道的17件事

这篇影评可能有剧透

关于《超能陆战队》你应该知道的17件事 1.据美术设计Scott Watanabe介绍，影片发生在一个平行宇宙，在这个宇宙中，1906年旧金山大地震后，一群日本移民利用特殊的移动建筑技术重建了它。这座城市被重新命名为“旧京山 San Fransokyo”。 2.“白胖子”的面部设计让人想起一种... (展开)
162 8 23回应 收起
楚平 2015-03-08 22:31:38

## 史上最忧郁机器人马文，比大白还要萌四十二倍

在这里发这个贴子，有点砸场子的意思。可是我忍不住。 因为我心中最萌的机器人，并非当红的大白，是《银河系漫游指南》里的马文。 马文是个患有忧郁症的机器人。 它圆圆的脑袋容量相当于一颗行星，聪明绝顶，起码它认为比自己的主人要聪明。主人对他喊："Freeze（意思是别... (展开)
96 6 19回应 收起

> 更多影评 927篇

添加新讨论

## 讨论区 · · · · · ·

后面再造的那个大白到底还是不是原本的大白？ | 来自kongbaijun |  | 2022-11-21 08:26:49
这电影能top250？不服啊 | 来自海边的鲁仲连 | 40 回应 | 2022-09-30 03:21:33
超能路战队 | 来自豆友w-xinTsYE4 |  | 2022-08-03 15:25:18
影片最后，芯片是什么时候拔出握在大白手里的？ | 来自菠菜肉圆汤 | 1 回应 | 2022-07-29 23:40:04
他哥哥为什么总戴着帽子 | 来自燃点° |  | 2022-07-25 23:28:32

> 去这部影片的讨论区（全部114条）

## 关于《超能陆战队》的问题 · · · · · · ( 全部141个 )

- 为什么大白不把手扔出去，自己跟他们一起回来？ 60人回答
- 背景为什么选择日本？ 41人回答

> 全部141个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 芒果TV VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 2014新电影（这些，可以期待） (桃桃林林)
- 评价人数超过十万的电影 (依然饭特稀)

## 谁在看这部电影 · · · · · ·

- Y
  1分钟前 看过
- 豆友ZYW7_fy9t8
  2分钟前 看过
- Victor
  2分钟前 看过

1840014人看过 / 112041人想看

订阅超能陆战队的评论:
feed: rss 2.0